voice_command_manager library

Classes

CommandHandler
Handles initialization and listening with SpeechToText.
VoiceCommandManager
A widget that manages continuous background voice command listening. Wrap your app or a specific widget tree with this manager.